@@ -7,18 +7,17 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-# flake8: noqa: F403
+# ruff: noqa: F403
 
 from holidays.constants import *
+from holidays.deprecations.v1_incompatibility import *
 from holidays.holiday_base import *
 from holidays.registry import EntityLoader
 from holidays.utils import *
-
-__version__ = "0.46"
-
+from holidays.version import __version__  # noqa: F401
 
 EntityLoader.load("countries", globals())
 EntityLoader.load("financial", globals())
