@@ -7,14 +7,13 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from datetime import timedelta as td
 from gettext import gettext as tr
 
-from holidays.calendars.gregorian import APR, AUG
+from holidays.calendars.gregorian import APR, AUG, _timedelta
 from holidays.groups import ChristianHolidays, InternationalHolidays
 from holidays.holiday_base import HolidayBase
 
@@ -31,8 +30,10 @@ class Aruba(HolidayBase, ChristianHolidays, InternationalHolidays):
     """
 
     country = "AW"
-    default_language = "pap"
-    supported_languages = ("en_US", "nl", "pap", "uk")
+    default_language = "pap_AW"
+    supported_languages = ("en_US", "nl", "pap_AW", "uk")
+    # AUG 1947: Autonomous State status in the Kingdom of the Netherlands.
+    start_year = 1947
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -40,10 +41,6 @@ class Aruba(HolidayBase, ChristianHolidays, InternationalHolidays):
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        # AUG 1947: Autonomous State status in the Kingdom of the Netherlands.
-        if self._year <= 1946:
-            return None
-
         # Aña Nobo.
         # Status: In-Use.
 
@@ -118,7 +115,7 @@ class Aruba(HolidayBase, ChristianHolidays, InternationalHolidays):
         else:
             dt = (AUG, 31)
         if self._is_sunday(dt):
-            dt = date(self._year, *dt) + td(days=-1 if self._year >= 1980 else +1)
+            dt = _timedelta(date(self._year, *dt), -1 if self._year >= 1980 else +1)
         self._add_holiday(name, dt)
 
         # Dia di Labor/Dia di Obrero.
