@@ -7,12 +7,11 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
 from gettext import gettext as tr
-from typing import Set
 
 from holidays.calendars.julian_revised import JULIAN_REVISED_CALENDAR
 from holidays.constants import PUBLIC, SCHOOL
@@ -49,6 +48,7 @@ class Bulgaria(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
     observed_label = tr("%s (почивен ден)")
     supported_categories = (PUBLIC, SCHOOL)
     supported_languages = ("bg", "en_US", "uk")
+    start_year = 1990
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self, JULIAN_REVISED_CALENDAR)
@@ -57,7 +57,7 @@ class Bulgaria(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
         kwargs.setdefault("observed_since", 2017)
         super().__init__(*args, **kwargs)
 
-    def _populate_observed(self, dts: Set[date], excluded_names: Set[str]) -> None:
+    def _populate_observed(self, dts: set[date], excluded_names: set[str]) -> None:
         for dt in sorted(dts):
             if not self._is_observed(dt):
                 continue
@@ -66,9 +66,6 @@ class Bulgaria(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
                     self._add_observed(dt, name)
 
     def _populate_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         dts_observed = set()
 
         # New Year's Day.
@@ -130,9 +127,6 @@ class Bulgaria(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
             )
 
     def _populate_school_holidays(self):
-        if self._year <= 1989:
-            return None
-
         # National Awakening Day.
         self._add_holiday_nov_1(tr("Ден на народните будители"))
 
