@@ -7,11 +7,12 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
 from gettext import gettext as tr
+from typing import Optional
 
 from holidays.calendars.gregorian import MAR, APR, JUN, JUL, SEP
 from holidays.constants import GOVERNMENT, OPTIONAL, PUBLIC
@@ -30,12 +31,13 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
     """
     References:
         - https://en.wikipedia.org/wiki/Public_holidays_in_Canada
-        - https://web.archive.org/web/20130703014214/http://www.hrsdc.gc.ca/eng/labour/overviews/employment_standards/holidays.shtml  # noqa: E501
+        - https://web.archive.org/web/20130703014214/http://www.hrsdc.gc.ca/eng/labour/overviews/employment_standards/holidays.shtml
         - https://www.alberta.ca/alberta-general-holidays
-        - https://www2.gov.bc.ca/gov/content/employment-business/employment-standards-advice/employment-standards/statutory-holidays  # noqa: E501
+        - https://www2.gov.bc.ca/gov/content/employment-business/employment-standards-advice/employment-standards/statutory-holidays
         - http://web2.gov.mb.ca/laws/statutes/ccsm/r120e.php
-        - https://www2.gnb.ca/content/gnb/en/departments/elg/local_government/content/governance/content/days_of_rest_act.html  # noqa: E501
+        - https://www2.gnb.ca/content/gnb/en/departments/elg/local_government/content/governance/content/days_of_rest_act.html
         - https://www.ontario.ca/document/your-guide-employment-standards-act-0/public-holidays
+        - https://www.gov.nu.ca/en/print/pdf/node/52266
         - https://www.officeholidays.com/countries/canada/
         - https://www.timeanddate.com/holidays/canada/
     """
@@ -61,6 +63,7 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
         "YT",
     )
     supported_languages = ("ar", "en_CA", "en_US", "fr", "th")
+    start_year = 1867
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -69,7 +72,7 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
         kwargs.setdefault("observed_rule", SAT_SUN_TO_NEXT_MON)
         super().__init__(*args, **kwargs)
 
-    def _get_nearest_monday(self, *args) -> date:
+    def _get_nearest_monday(self, *args) -> Optional[date]:
         return self._get_observed_date(date(self._year, *args), rule=ALL_TO_NEAREST_MON)
 
     def _add_statutory_holidays(self):
@@ -98,9 +101,6 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
         self._add_christmas_day(tr("Christmas Day"))
 
     def _populate_public_holidays(self):
-        if self._year <= 1866:
-            return None
-
         self._add_statutory_holidays()
 
         self._add_observed(self._christmas_day)
@@ -108,9 +108,6 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
     def _populate_government_holidays(self):
         """Holidays for federally regulated workplaces."""
 
-        if self._year <= 1866:
-            return None
-
         self._add_statutory_holidays()
 
         if self._year >= 1953:
@@ -140,9 +137,6 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
         )
 
     def _populate_optional_holidays(self):
-        if self._year <= 1866:
-            return None
-
         # Christmas Day.
         self._add_observed(
             self._add_christmas_day(tr("Christmas Day")), rule=SAT_SUN_TO_NEXT_MON_TUE
@@ -242,14 +236,13 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
 
     def _populate_subdiv_mb_optional_holidays(self):
         if self._year >= 1900:
-            name = (
+            self._add_holiday_1st_mon_of_aug(
                 # Terry Fox Day.
                 tr("Terry Fox Day")
                 if self._year >= 2015
                 # Civic Holiday.
                 else tr("Civic Holiday")
             )
-            self._add_holiday_1st_mon_of_aug(name)
 
         if self._year >= 1931:
             # Remembrance Day.
@@ -293,16 +286,16 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
 
     def _populate_subdiv_nl_optional_holidays(self):
         if self._year >= 1900:
-            # St. Patrick's Day.
-            self._add_holiday(tr("St. Patrick's Day"), self._get_nearest_monday(MAR, 17))
+            # Saint Patrick's Day.
+            self._add_holiday(tr("Saint Patrick's Day"), self._get_nearest_monday(MAR, 17))
 
         if self._year >= 1990:
             # Nearest Monday to April 23
             # 4/26 is the Monday closer to 4/23 in 2010
             # but the holiday was observed on 4/19? Crazy Newfies!
             dt = date(2010, APR, 19) if self._year == 2010 else self._get_nearest_monday(APR, 23)
-            # St. George's Day.
-            self._add_holiday(tr("St. George's Day"), dt)
+            # Saint George's Day.
+            self._add_holiday(tr("Saint George's Day"), dt)
 
         if self._year >= 1997:
             # Discovery Day.
@@ -360,6 +353,10 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
             # Victoria Day.
             self._add_holiday_1st_mon_before_may_24(tr("Victoria Day"))
 
+        if self._year >= 2020:
+            # Nunavut Day.
+            self._add_holiday_jul_9(tr("Nunavut Day"))
+
         if self._year >= 1900:
             # Civic Holiday.
             self._add_holiday_1st_mon_of_aug(tr("Civic Holiday"))
@@ -375,8 +372,7 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
             self._add_remembrance_day(tr("Remembrance Day"))
 
     def _populate_subdiv_nu_optional_holidays(self):
-        if self._year >= 2000:
-            # Nunavut Day.
+        if 2000 <= self._year <= 2019:
             name = tr("Nunavut Day")
             if self._year == 2000:
                 self._add_holiday_apr_1(name)
@@ -428,8 +424,8 @@ class Canada(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stat
 
         if self._year >= 1925:
             self._add_observed(
-                # St. Jean Baptiste Day.
-                self._add_saint_johns_day(tr("St. Jean Baptiste Day")),
+                # Saint John the Baptist Day.
+                self._add_saint_johns_day(tr("Saint Jean Baptiste Day")),
                 rule=SUN_TO_NEXT_MON,
             )
 
