@@ -7,19 +7,21 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from datetime import timedelta as td
 from gettext import gettext as tr
-from typing import Tuple
 
-from holidays.calendars.gregorian import JUN, SEP
+from holidays.calendars.gregorian import JUN, SEP, DEC
+from holidays.constants import BANK, PUBLIC
 from holidays.groups import ChristianHolidays, InternationalHolidays, StaticHolidays
 from holidays.observed_holiday_base import (
     ObservedHolidayBase,
+    MON_ONLY,
+    MON_FRI_ONLY,
     TUE_TO_PREV_FRI,
     WED_TO_NEXT_FRI,
+    FRI_ONLY,
     WORKDAY_TO_NEAREST_MON,
 )
 
@@ -27,27 +29,32 @@ from holidays.observed_holiday_base import (
 class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
     """
     References:
-    - https://www.feriados.cl
-    - http://www.feriadoschilenos.cl/ (excellent history)
-    - https://es.wikipedia.org/wiki/Anexo:D%C3%ADas_feriados_en_Chile
-    - Law 2.977 (established official Chile holidays in its current form)
-    - Law 20.983 (Day after New Year's Day, if it's a Sunday)
-    - Law 19.668 (floating Monday holiday)
-    - Law 19.668 (Corpus Christi)
-    - Law 2.200, (Labour Day)
-    - Law 18.018 (Labour Day renamed)
-    - Law 16.840, Law 18.432 (Saint Peter and Saint Paul)
-    - Law 20.148 (Day of Virgin of Carmen)
-    - Law 18.026 (Day of National Liberation)
-    - Law 19.588, Law 19.793 (Day of National Unity)
-    - Law 20.983 (National Holiday Friday preceding Independence Day)
-    - Law 20.215 (National Holiday Monday preceding Independence Day)
-    - Law 20.215 (National Holiday Friday following Army Day)
-    - Decree-law 636, Law 8.223
-    - Law 3.810 (Columbus Day)
-    - Law 20.299 (National Day of the Evangelical and Protestant Churches)
-    - Law 20.663 (Región de Arica y Parinacota)
-    - Law 20.678 (Región de Ñuble)
+        - https://www.feriados.cl
+        - `Excellent history of Chile holidays <http://www.feriadoschilenos.cl>`_
+        - https://es.wikipedia.org/wiki/Anexo:D%C3%ADas_feriados_en_Chile
+        - Law 2.977 (established official Chile holidays in its current form)
+        - Law 20.983 (Day after New Year's Day, if it's a Sunday)
+        - Law 19.668 (floating Monday holiday)
+        - Law 19.668 (Corpus Christi)
+        - Law 2.200, (Labour Day)
+        - Law 18.018 (Labour Day renamed)
+        - Law 16.840, Law 18.432 (Saint Peter and Saint Paul)
+        - Law 20.148 (Day of Virgin of Carmen)
+        - Law 18.026 (Day of National Liberation)
+        - Law 19.588, Law 19.793 (Day of National Unity)
+        - Law 20.983 (National Holiday Friday preceding Independence Day)
+        - Law 20.215 (National Holiday Monday preceding Independence Day)
+        - Law 20.215 (National Holiday Friday following Army Day)
+        - Decree-law 636, Law 8.223
+        - Law 3.810 (Columbus Day)
+        - Law 20.299 (National Day of the Evangelical and Protestant Churches)
+        - Law 20.663 (Región de Arica y Parinacota)
+        - Law 20.678 (Región de Ñuble)
+        - `Law 19.656 (Dec 31, 1999 holiday) <https://www.bcn.cl/leychile/navegar?idNorma=149328&idVersion=1999-12-15>`_
+        - `Law 12.051 (bank holidays Jun 30 and Dec 31) <https://www.bcn.cl/leychile/navegar?idNorma=27013&idVersion=1956-07-12>`_
+        - `Decree-law 1.171 (eliminate Jun 30) <https://www.bcn.cl/leychile/navegar?idNorma=6507&idVersion=1975-09-05>`_
+        - `Law 19.528 (eliminate Dec 31) <https://www.bcn.cl/leychile/navegar?idNorma=76630&idVersion=1997-11-04>`_
+        - `Law 19.559 (restore Dec 31) <https://www.bcn.cl/leychile/navegar?idNorma=97758&idVersion=1998-04-16>`_
     """
 
     country = "CL"
@@ -70,7 +77,9 @@ class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stati
         "TA",
         "VS",
     )
+    supported_categories = (BANK, PUBLIC)
     supported_languages = ("en_US", "es", "uk")
+    start_year = 1915
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -81,13 +90,10 @@ class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stati
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        if self._year <= 1914:
-            return None
-
         # New Year's Day.
-        jan_1 = self._add_new_years_day(tr("Año Nuevo"))
-        if self._year >= 2017 and self._is_sunday(jan_1):
-            self._add_new_years_day_two(tr("Feriado nacional"))
+        self._add_new_years_day(tr("Año Nuevo"))
+        if self._year >= 2017:
+            self._add_observed(self._add_new_years_day_two(tr("Feriado nacional")), rule=MON_ONLY)
 
         # Good Friday.
         self._add_good_friday(tr("Viernes Santo"))
@@ -100,11 +106,12 @@ class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stati
             self._add_ascension_thursday(tr("Ascensión del Señor"))
 
         if self._year <= 1967 or 1987 <= self._year <= 2006:
-            self._add_holiday(
-                # Corpus Christi.
-                tr("Corpus Christi"),
-                self._easter_sunday + td(days=+60 if self._year <= 1999 else +57),
-            )
+            # Corpus Christi.
+            name = tr("Corpus Christi")
+            if self._year <= 1999:
+                self._add_corpus_christi_day(name)
+            else:
+                self._add_holiday_57_days_past_easter(name)
 
         if self._year >= 1932:
             # Labor Day.
@@ -122,7 +129,7 @@ class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stati
                 self._add_holiday(name, self._summer_solstice_date)
 
         if self._year <= 1967 or self._year >= 1986:
-            # Saint Peter and Saint Paul.
+            # Saint Peter and Saint Paul's Day.
             self._move_holiday(self._add_saints_peter_and_paul_day(tr("San Pedro y San Pablo")))
 
         if self._year >= 2007:
@@ -136,39 +143,38 @@ class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stati
             # Day of National Liberation.
             self._add_holiday_sep_11(tr("Día de la Liberación Nacional"))
         elif 1999 <= self._year <= 2001:
-            self._add_holiday_1st_mon_of_sep(
-                # Day of National Unity.
-                tr("Día de la Unidad Nacional")
+            # Day of National Unity.
+            self._add_holiday_1st_mon_of_sep(tr("Día de la Unidad Nacional"))
+
+        if self._year >= 2007:
+            self._add_observed(
+                # National Holiday.
+                self._add_holiday_sep_17(tr("Fiestas Patrias")),
+                rule=MON_FRI_ONLY if self._year >= 2017 else MON_ONLY,
             )
 
-        if self._year >= 2017 and self._is_saturday(SEP, 18):
-            # National Holiday.
-            self._add_holiday_sep_17(tr("Fiestas Patrias"))
-
-        if self._year >= 2007 and self._is_tuesday(SEP, 18):
-            self._add_holiday_sep_17(tr("Fiestas Patrias"))
-
         # Independence Day.
         self._add_holiday_sep_18(tr("Día de la Independencia"))
 
         # Army Day.
         self._add_holiday_sep_19(tr("Día de las Glorias del Ejército"))
 
-        if self._year >= 2008 and self._is_thursday(SEP, 19):
-            self._add_holiday_sep_20(tr("Fiestas Patrias"))
+        if self._year >= 2008:
+            self._add_observed(self._add_holiday_sep_20(tr("Fiestas Patrias")), rule=FRI_ONLY)
 
         if 1932 <= self._year <= 1944:
             self._add_holiday_sep_20(tr("Fiestas Patrias"))
 
         if self._year >= 1922 and self._year != 1973:
-            name = (
-                # Meeting of Two Worlds' Day.
-                tr("Día del Encuentro de dos Mundos")
-                if self._year >= 2000
-                # Columbus Day.
-                else tr("Día de la Raza")
+            self._move_holiday(
+                self._add_columbus_day(
+                    # Meeting of Two Worlds' Day.
+                    tr("Día del Encuentro de dos Mundos")
+                    if self._year >= 2000
+                    # Columbus Day.
+                    else tr("Día de la Raza")
+                )
             )
-            self._move_holiday(self._add_columbus_day(name))
 
         if self._year >= 2008:
             # This holiday is moved to the preceding Friday if it falls on a Tuesday,
@@ -206,8 +212,17 @@ class Chile(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, Stati
                 tr("Nacimiento del Prócer de la Independencia (Chillán y Chillán Viejo)")
             )
 
+    def _populate_bank_holidays(self):
+        # Bank Holiday.
+        name = tr("Feriado bancario")
+        if 1957 <= self._year <= 1975:
+            self._add_holiday_jun_30(name)
+
+        if self._year >= 1956 and self._year != 1997:
+            self._add_holiday_dec_31(name)
+
     @property
-    def _summer_solstice_date(self) -> Tuple[int, int]:
+    def _summer_solstice_date(self) -> tuple[int, int]:
         day = 20
         if (self._year % 4 > 1 and self._year <= 2046) or (
             self._year % 4 > 2 and self._year <= 2075
@@ -225,7 +240,10 @@ class CHL(Chile):
 
 
 class ChileStaticHolidays:
+    # National Holiday.
+    national_holiday = tr("Feriado nacional")
+
     special_public_holidays = {
-        # National Holiday.
-        2022: (SEP, 16, tr("Feriado nacional")),
+        1999: (DEC, 31, national_holiday),
+        2022: (SEP, 16, national_holiday),
     }
