@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
@@ -27,6 +27,7 @@ class Croatia(HolidayBase, ChristianHolidays, InternationalHolidays):
     country = "HR"
     default_language = "hr"
     supported_languages = ("en_US", "hr", "uk")
+    start_year = 1992
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -34,9 +35,6 @@ class Croatia(HolidayBase, ChristianHolidays, InternationalHolidays):
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        if self._year <= 1991:
-            return None
-
         # New Year's Day.
         self._add_new_years_day(tr("Nova godina"))
 
@@ -69,14 +67,13 @@ class Croatia(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Anti-Fascist Struggle Day.
         self._add_holiday_jun_22(tr("Dan antifašističke borbe"))
 
-        name = (
+        self._add_holiday_aug_5(
             # Victory and Homeland Thanksgiving Day and Croatian Veterans Day.
             tr("Dan pobjede i domovinske zahvalnosti i Dan hrvatskih branitelja")
             if self._year >= 2008
             # Victory and Homeland Thanksgiving Day.
             else tr("Dan pobjede i domovinske zahvalnosti")
         )
-        self._add_holiday_aug_5(name)
 
         # Assumption Day.
         self._add_assumption_of_mary_day(tr("Velika Gospa"))
@@ -100,7 +97,7 @@ class Croatia(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Christmas Day.
         self._add_christmas_day(tr("Božić"))
 
-        # St. Stephen's Day.
+        # Saint Stephen's Day.
         self._add_christmas_day_two(tr("Sveti Stjepan"))
 
 
