@@ -7,10 +7,9 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from datetime import timedelta as td
 from gettext import gettext as tr
 
 from holidays.constants import OPTIONAL, PUBLIC
@@ -56,7 +55,7 @@ class Denmark(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         if self._year <= 2023:
             # Great Day of Prayers.
-            self._add_holiday(tr("Store bededag"), self._easter_sunday + td(days=+26))
+            self._add_holiday_26_days_past_easter(tr("Store bededag"))
 
         # Ascension Day.
         self._add_ascension_thursday(tr("Kristi himmelfartsdag"))
@@ -74,7 +73,7 @@ class Denmark(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_christmas_day_two(tr("Anden juledag"))
 
     def _populate_optional_holidays(self):
-        # International Workers' Day.
+        # Workers' Day.
         self._add_labor_day(tr("Arbejdernes kampdag"))
 
         # Constitution Day.
