@@ -7,12 +7,13 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
 
-from holidays.calendars.gregorian import MAY, OCT
+from holidays.calendars.gregorian import MAY, JUN, OCT
+from holidays.constants import CATHOLIC, PUBLIC
 from holidays.groups import ChristianHolidays, InternationalHolidays, StaticHolidays
 from holidays.holiday_base import HolidayBase
 
@@ -28,39 +29,21 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
     doesn't really make sense to include the days from the two former
     countries.
 
-    Note that Germany doesn't have rules for holidays that happen on a
-    Sunday. Those holidays are still holiday days but there is no additional
-    day to make up for the "lost" day.
-
-    Also note that German holidays are partly declared by each province there
-    are some weired edge cases:
-
-        - "Mariä Himmelfahrt" is only a holiday in Bavaria (BY) if your
-          municipality is mostly catholic which in term depends on census data.
-          Since we don't have this data but most municipalities in Bavaria
-          *are* mostly catholic, we count that as holiday for whole Bavaria.
-          We added BYP for the municipality in Bavaria with more protestants.
-          Here this is excluded.
-        - There is an "Augsburger Friedensfest" which only exists in the town
-          Augsburg. This is excluded for Bavaria.
-        - "Gründonnerstag" (Thursday before easter) is not a holiday but pupils
-           don't have to go to school (but only in Baden Württemberg) which is
-           solved by adjusting school holidays to include this day. It is
-           excluded from our list.
-        - "Fronleichnam" is a holiday in certain, explicitly defined
-          municipalities in Saxony (SN) and Thuringia (TH). We exclude it from
-          both provinces.
+    "Mariä Himmelfahrt" is only a holiday in Bavaria (BY) and "Fronleichnam"
+    in Saxony (SN) and Thuringia (TH) if municipality is mostly catholic which
+    in term depends on census data. It's listed in "CATHOLIC" category for these provinces.
     """
 
     country = "DE"
     default_language = "de"
-    supported_languages = ("de", "en_US", "uk")
+    supported_categories = (CATHOLIC, PUBLIC)
+    supported_languages = ("de", "en_US", "th", "uk")
     subdivisions = (
+        # ISO 3166-2:DE
         "BB",
         "BE",
         "BW",
         "BY",
-        "BYP",
         "HB",
         "HE",
         "HH",
@@ -74,6 +57,26 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
         "ST",
         "TH",
     )
+    subdivisions_aliases = {
+        "Brandenburg": "BB",
+        "Berlin": "BE",
+        "Baden-Württemberg": "BW",
+        "Bayern": "BY",
+        "Bremen": "HB",
+        "Hessen": "HE",
+        "Hamburg": "HH",
+        "Mecklenburg-Vorpommern": "MV",
+        "Niedersachsen": "NI",
+        "Nordrhein-Westfalen": "NW",
+        "Rheinland-Pfalz": "RP",
+        "Schleswig-Holstein": "SH",
+        "Saarland": "SL",
+        "Sachsen": "SN",
+        "Sachsen-Anhalt": "ST",
+        "Thüringen": "TH",
+    }
+    _deprecated_subdivisions = ("BYP",)
+    start_year = 1990
 
     def __init__(self, *args, **kwargs) -> None:
         ChristianHolidays.__init__(self)
@@ -82,9 +85,6 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             # New Year's Day.
             self._add_new_years_day(tr("Neujahr"))
@@ -117,10 +117,10 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
         # Second Day of Christmas.
         self._add_christmas_day_two(tr("Zweiter Weihnachtstag"))
 
-    def _populate_subdiv_bb_public_holidays(self):
-        if self._year <= 1989:
-            return None
+        if self.subdiv == "BYP":
+            self._populate_subdiv_by_public_holidays()
 
+    def _populate_subdiv_bb_public_holidays(self):
         if self._year >= 1991:
             # Easter Sunday.
             self._add_easter_sunday(tr("Ostersonntag"))
@@ -132,17 +132,11 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
         self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_be_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2019:
             # International Women's Day.
             self._add_womens_day(tr("Internationaler Frauentag"))
 
     def _populate_subdiv_bw_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             # Epiphany.
             self._add_epiphany_day(tr("Heilige Drei Könige"))
@@ -154,94 +148,56 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
         self._add_all_saints_day(tr("Allerheiligen"))
 
     def _populate_subdiv_by_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             self._add_epiphany_day(tr("Heilige Drei Könige"))
             self._add_corpus_christi_day(tr("Fronleichnam"))
 
+        self._add_all_saints_day(tr("Allerheiligen"))
+
+    def _populate_subdiv_by_catholic_holidays(self):
+        if self._year >= 1991:
             # Assumption Day.
             self._add_assumption_of_mary_day(tr("Mariä Himmelfahrt"))
 
-        self._add_all_saints_day(tr("Allerheiligen"))
-
-    def _populate_subdiv_byp_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
-        if self._year >= 1991:
-            self._add_epiphany_day(tr("Heilige Drei Könige"))
-            self._add_corpus_christi_day(tr("Fronleichnam"))
-
-        self._add_all_saints_day(tr("Allerheiligen"))
-
     def _populate_subdiv_hb_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2018:
             self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_he_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             self._add_corpus_christi_day(tr("Fronleichnam"))
 
     def _populate_subdiv_hh_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2018:
             self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_mv_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2023:
             self._add_womens_day(tr("Internationaler Frauentag"))
 
         self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_ni_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2018:
             self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_nw_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             self._add_corpus_christi_day(tr("Fronleichnam"))
 
         self._add_all_saints_day(tr("Allerheiligen"))
 
     def _populate_subdiv_rp_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             self._add_corpus_christi_day(tr("Fronleichnam"))
 
         self._add_all_saints_day(tr("Allerheiligen"))
 
     def _populate_subdiv_sh_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2018:
             self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_sl_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 1991:
             self._add_corpus_christi_day(tr("Fronleichnam"))
             self._add_assumption_of_mary_day(tr("Mariä Himmelfahrt"))
@@ -249,33 +205,32 @@ class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
         self._add_all_saints_day(tr("Allerheiligen"))
 
     def _populate_subdiv_sn_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         self._add_holiday_oct_31(tr("Reformationstag"))
 
         if self._year >= 1995:
             self._add_holiday_1st_wed_before_nov_22(tr("Buß- und Bettag"))
 
-    def _populate_subdiv_st_public_holidays(self):
-        if self._year <= 1989:
-            return None
+    def _populate_subdiv_sn_catholic_holidays(self):
+        if self._year >= 1991:
+            self._add_corpus_christi_day(tr("Fronleichnam"))
 
+    def _populate_subdiv_st_public_holidays(self):
         if self._year >= 1991:
             self._add_epiphany_day(tr("Heilige Drei Könige"))
 
         self._add_holiday_oct_31(tr("Reformationstag"))
 
     def _populate_subdiv_th_public_holidays(self):
-        if self._year <= 1989:
-            return None
-
         if self._year >= 2019:
             # World Children's Day.
             self._add_holiday_sep_20(tr("Weltkindertag"))
 
         self._add_holiday_oct_31(tr("Reformationstag"))
 
+    def _populate_subdiv_th_catholic_holidays(self):
+        if self._year >= 1991:
+            self._add_corpus_christi_day(tr("Fronleichnam"))
+
 
 class DE(Germany):
     pass
@@ -286,6 +241,13 @@ class DEU(Germany):
 
 
 class GermanyStaticHolidays:
+    """
+    References:
+     - https://www.stuttgarter-zeitung.de/inhalt.reformationstag-2017-einmalig-bundesweiter-feiertag.b7e189b3-a33d-41a3-a0f4-141cd13df54e.html
+     - https://www.bbc.com/news/world-europe-52574748
+     - https://gesetze.berlin.de/bsbe/document/jlr-FeiertGBEV8P1
+    """
+
     special_public_holidays = {
         2017: (OCT, 31, tr("Reformationstag")),
     }
@@ -301,4 +263,16 @@ class GermanyStaticHolidays:
                 "und der Beendigung des Zweiten Weltkriegs in Europa"
             ),
         ),
+        2025: (
+            MAY,
+            8,
+            # 80th anniversary of the liberation from Nazism and
+            # the end of the Second World War in Europe.
+            tr(
+                "80. Jahrestag der Befreiung vom Nationalsozialismus "
+                "und der Beendigung des Zweiten Weltkriegs in Europa"
+            ),
+        ),
+        # 75th anniversary of the East German uprising of 1953.
+        2028: (JUN, 17, tr("75. Jahrestag des Aufstandes vom 17. Juni 1953")),
     }
