@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
@@ -39,6 +39,7 @@ class Hungary(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
       - `2021 <https://njt.hu/jogszabaly/2020-14-20-7Q>`_
       - `2022 <https://njt.hu/jogszabaly/2021-23-20-7Q>`_
       - `2024 <https://njt.hu/jogszabaly/2023-15-20-8P>`_
+      - `2025 <https://njt.hu/jogszabaly/2024-11-20-2X>`_
     """
 
     country = "HU"
@@ -53,7 +54,7 @@ class Hungary(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
 
     def _populate_public_holidays(self):
         # New Year's Day.
-        self._add_new_years_day(self.tr("Újév"))
+        self._add_new_years_day(tr("Újév"))
 
         if 1945 <= self._year <= 1950 or self._year >= 1989:
             # National Day.
@@ -89,7 +90,7 @@ class Hungary(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolid
             tr("A kenyér ünnepe")
             if 1950 <= self._year <= 1989
             # State Foundation Day.
-            else tr("Az államalapítás ünnepe"),
+            else tr("Az államalapítás ünnepe")
         )
 
         if self._year >= 1991:
@@ -193,4 +194,9 @@ class HungaryStaticHolidays:
             (DEC, 24, DEC, 7),
             (DEC, 27, DEC, 14),
         ),
+        2025: (
+            (MAY, 2, MAY, 17),
+            (OCT, 24, OCT, 18),
+            (DEC, 24, DEC, 13),
+        ),
     }
