@@ -20,6 +20,7 @@ from holidays.calendars import (
 from holidays.calendars.gregorian import JAN, FEB, MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV, DEC
 from holidays.constants import GOVERNMENT, PUBLIC
 from holidays.groups import (
+    BalineseSakaCalendarHolidays,
     BuddhistCalendarHolidays,
     ChineseCalendarHolidays,
     ChristianHolidays,
@@ -32,6 +33,7 @@ from holidays.observed_holiday_base import ObservedHolidayBase
 
 class Indonesia(
     ObservedHolidayBase,
+    BalineseSakaCalendarHolidays,
     BuddhistCalendarHolidays,
     ChineseCalendarHolidays,
     ChristianHolidays,
@@ -44,10 +46,8 @@ class Indonesia(
     - https://en.wikipedia.org/wiki/Public_holidays_in_Indonesia
     - https://id.wikipedia.org/wiki/Hari_libur_di_Indonesia
     - https://www.liburnasional.com/sejarah/
-    - https://id.wikipedia.org/wiki/Indonesia_dalam_tahun_1963 (1963-2024)
+    - https://id.wikipedia.org/wiki/Indonesia_dalam_tahun_1963 (1963-2025)
     - https://www.timeanddate.com/holidays/indonesia
-    - https://en.wikipedia.org/wiki/Nyepi
-    - https://bali.com/bali/travel-guide/culture/nyepi-balinese-new-year/
     """
 
     country = "ID"
@@ -62,12 +62,19 @@ class Indonesia(
     supported_categories = (GOVERNMENT, PUBLIC)
     start_year = 1946
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+        """
+        :param islamic_show_estimated:
+            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        """
+        BalineseSakaCalendarHolidays.__init__(self)
         BuddhistCalendarHolidays.__init__(self, cls=IndonesiaBuddhistHolidays, show_estimated=True)
         ChineseCalendarHolidays.__init__(self, cls=IndonesiaChineseHolidays, show_estimated=True)
         ChristianHolidays.__init__(self)
         InternationalHolidays.__init__(self)
-        IslamicHolidays.__init__(self, cls=IndonesiaIslamicHolidays)
+        IslamicHolidays.__init__(
+            self, cls=IndonesiaIslamicHolidays, show_estimated=islamic_show_estimated
+        )
         StaticHolidays.__init__(self, cls=IndonesiaStaticHolidays)
         super().__init__(*args, **kwargs)
 
@@ -148,59 +155,8 @@ class Indonesia(
 
         # Keputusan Presiden no 3 tahun 1983. (1983-01-19; Added Nationally)
         if self._year >= 1983:
-            dates_obs = {
-                1983: (MAR, 15),
-                1984: (MAR, 4),
-                1985: (MAR, 22),
-                1986: (MAR, 12),
-                1987: (MAR, 31),
-                1988: (MAR, 19),
-                1989: (MAR, 9),
-                1990: (MAR, 27),
-                1991: (MAR, 17),
-                1992: (MAR, 5),
-                1993: (MAR, 24),
-                1994: (MAR, 12),
-                1995: (APR, 1),
-                1996: (MAR, 21),
-                1997: (APR, 9),
-                1998: (MAR, 29),
-                1999: (MAR, 18),
-                2000: (APR, 4),
-                2001: (MAR, 25),
-                2002: (APR, 13),
-                2003: (APR, 2),
-                2004: (MAR, 22),
-                2005: (MAR, 11),
-                2006: (MAR, 30),
-                2007: (MAR, 19),
-                2008: (MAR, 7),
-                2009: (MAR, 26),
-                2010: (MAR, 16),
-                2011: (MAR, 5),
-                2012: (MAR, 23),
-                2013: (MAR, 12),
-                2014: (MAR, 31),
-                2015: (MAR, 21),
-                2016: (MAR, 9),
-                2017: (MAR, 28),
-                2018: (MAR, 17),
-                2019: (MAR, 7),
-                2020: (MAR, 25),
-                2021: (MAR, 14),
-                2022: (MAR, 3),
-                2023: (MAR, 22),
-                2024: (MAR, 11),
-                2025: (MAR, 29),
-                2026: (MAR, 19),
-                2027: (MAR, 8),
-                2028: (MAR, 26),
-                2029: (MAR, 15),
-                2030: (MAR, 5),
-            }
-            if self._year in dates_obs:
-                # Day of Silence.
-                self._add_holiday(tr("Hari Suci Nyepi"), dates_obs[self._year])
+            # Day of Silence.
+            self._add_nyepi(tr("Hari Suci Nyepi"))
 
             # Vesak Day.
             self._add_vesak(tr("Hari Raya Waisak"))
