@@ -7,22 +7,31 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from datetime import timedelta as td
 from gettext import gettext as tr
-from typing import Tuple
 
-from holidays.calendars.gregorian import FEB, MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV
+from holidays.calendars.gregorian import (
+    FEB,
+    MAR,
+    APR,
+    MAY,
+    JUN,
+    JUL,
+    AUG,
+    SEP,
+    OCT,
+    NOV,
+    _timedelta,
+)
 from holidays.constants import BANK, PUBLIC
 from holidays.groups import InternationalHolidays, StaticHolidays
-from holidays.helpers import _normalize_tuple
-from holidays.holiday_base import HolidayBase
+from holidays.observed_holiday_base import ObservedHolidayBase, SUN_TO_NEXT_WORKDAY
 
 
-class Japan(HolidayBase, InternationalHolidays, StaticHolidays):
+class Japan(ObservedHolidayBase, InternationalHolidays, StaticHolidays):
     """
     References:
 
@@ -34,16 +43,45 @@ class Japan(HolidayBase, InternationalHolidays, StaticHolidays):
     default_language = "ja"
     supported_categories = (BANK, PUBLIC)
     supported_languages = ("en_US", "ja", "th")
+    start_year = 1949
+    end_year = 2099
 
     def __init__(self, *args, **kwargs) -> None:
         InternationalHolidays.__init__(self)
         StaticHolidays.__init__(self, cls=JapanStaticHolidays)
+        kwargs.setdefault("observed_rule", SUN_TO_NEXT_WORKDAY)
         super().__init__(*args, **kwargs)
 
-    def _populate_public_holidays(self):
-        if self._year < 1949 or self._year > 2099:
-            raise NotImplementedError
+    def _is_observed(self, dt: date) -> bool:
+        return dt >= date(1973, APR, 12)
 
+    def _populate_observed(self, dts: set[date]) -> None:
+        # When a national holiday falls on Sunday, next working day
+        # shall become a public holiday (振替休日) - substitute holiday.
+        for dt in sorted(dts):
+            # Substitute Holiday.
+            self._add_observed(dt, name=tr("振替休日"), show_observed_label=False)
+
+        # A weekday between national holidays becomes a holiday too (国民の休日) -
+        # national holiday.
+        # In 1986-2006 it was only May 4 (between Constitution Day and Children's Day).
+        # Since 2006, it may be only the day between Respect for the Aged Day and
+        # Autumnal Equinox Day (in September).
+        if self._year <= 1985:
+            return None
+        if self._year <= 2006:
+            may_4 = (MAY, 4)
+            if not self._is_monday(may_4) and not self._is_sunday(may_4):
+                # National Holiday.
+                self._add_holiday(tr("国民の休日"), may_4)
+        else:
+            for dt in dts:
+                if dt.month == SEP and _timedelta(dt, +2) in dts:
+                    # National Holiday.
+                    self._add_holiday(tr("国民の休日"), _timedelta(dt, +1))
+                    break
+
+    def _populate_public_holidays(self):
         dts_observed = set()
 
         # New Year's Day.
@@ -112,11 +150,7 @@ class Japan(HolidayBase, InternationalHolidays, StaticHolidays):
             }
             # Mountain Day.
             name = tr("山の日")
-            dts_observed.add(
-                self._add_holiday(name, dates[self._year])
-                if self._year in dates
-                else self._add_holiday_aug_11(name)
-            )
+            dts_observed.add(self._add_holiday(name, dates.get(self._year, (AUG, 11))))
 
         if self._year >= 1966:
             # Respect for the Aged Day.
@@ -161,45 +195,18 @@ class Japan(HolidayBase, InternationalHolidays, StaticHolidays):
             dts_observed.add(self._add_holiday_dec_23(tr("天皇誕生日")))
 
         if self.observed:
-            for month, day, _ in _normalize_tuple(
-                self.special_public_holidays.get(self._year, ())
-            ):
-                dts_observed.add(date(self._year, month, day))
-
-            # When a national holiday falls on Sunday, next working day
-            # shall become a public holiday (振替休日) - substitute holidays.
-            for dt in dts_observed.copy():
-                if not self._is_sunday(dt):
-                    continue
-                dt_observed = dt + td(days=+1)
-                while dt_observed in dts_observed:
-                    dt_observed += td(days=+1)
-                # Substitute Holiday.
-                dts_observed.add(self._add_holiday(tr("振替休日"), dt_observed))
-
-            # A weekday between national holidays becomes
-            # a holiday too (国民の休日) - citizens' holidays.
-            for dt in dts_observed:
-                if dt + td(days=+2) not in dts_observed:
-                    continue
-                dt_observed = dt + td(days=+1)
-                if self._is_sunday(dt_observed) or dt_observed in dts_observed:
-                    continue
-                # National Holiday.
-                self._add_holiday(tr("国民の休日"), dt_observed)
+            self._populate_observed(dts_observed)
 
     def _populate_bank_holidays(self):
-        if self._year < 1949 or self._year > 2099:
-            raise NotImplementedError
-
         # Bank Holiday.
         name = tr("銀行休業日")
+        self._add_new_years_day(name)
         self._add_new_years_day_two(name)
         self._add_new_years_day_three(name)
         self._add_new_years_eve(name)
 
     @property
-    def _vernal_equinox_date(self) -> Tuple[int, int]:
+    def _vernal_equinox_date(self) -> tuple[int, int]:
         day = 20
         if (
             (self._year % 4 == 0 and self._year <= 1956)
@@ -213,7 +220,7 @@ class Japan(HolidayBase, InternationalHolidays, StaticHolidays):
         return MAR, day
 
     @property
-    def _autumnal_equinox_date(self) -> Tuple[int, int]:
+    def _autumnal_equinox_date(self) -> tuple[int, int]:
         day = 23
         if self._year % 4 == 3 and self._year <= 1979:
             day = 24
@@ -235,6 +242,8 @@ class JPN(Japan):
 
 
 class JapanStaticHolidays:
+    national_holiday = tr("国民の休日")
+
     special_public_holidays = {
         1959: (APR, 10, tr("結婚の儀")),  # The Crown Prince marriage ceremony.
         1989: (FEB, 24, tr("大喪の礼")),  # State Funeral of Emperor Shōwa.
@@ -245,3 +254,10 @@ class JapanStaticHolidays:
             (OCT, 22, tr("即位礼正殿の儀が行われる日")),  # Enthronement ceremony.
         ),
     }
+
+    special_public_holidays_observed = {
+        2019: (
+            (APR, 30, national_holiday),
+            (MAY, 2, national_holiday),
+        ),
+    }
