@@ -7,14 +7,13 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from datetime import timedelta as td
 from gettext import gettext as tr
 
-from holidays.calendars.gregorian import APR, AUG
+from holidays.calendars.gregorian import APR, AUG, _timedelta
 from holidays.constants import OPTIONAL, PUBLIC
 from holidays.groups import ChristianHolidays, InternationalHolidays
 from holidays.holiday_base import HolidayBase
@@ -32,7 +31,8 @@ class Netherlands(HolidayBase, ChristianHolidays, InternationalHolidays):
     country = "NL"
     default_language = "nl"
     supported_categories = (OPTIONAL, PUBLIC)
-    supported_languages = ("en_US", "nl", "uk")
+    supported_languages = ("en_US", "fy", "nl", "uk")
+    start_year = 1801
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -65,7 +65,7 @@ class Netherlands(HolidayBase, ChristianHolidays, InternationalHolidays):
             else:
                 dt = date(self._year, AUG, 31)
             if self._is_sunday(dt):
-                dt += td(days=-1) if self._year >= 1980 else td(days=+1)
+                dt = _timedelta(dt, -1 if self._year >= 1980 else +1)
             self._add_holiday(name, dt)
 
         if self._year >= 1950 and self._year % 5 == 0:
