@@ -7,10 +7,9 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from datetime import timedelta as td
 from gettext import gettext as tr
 
 from holidays.constants import OPTIONAL, PUBLIC
@@ -40,6 +39,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
     country = "PT"
     default_language = "pt_PT"
     supported_categories = (OPTIONAL, PUBLIC)
+    start_year = 1801
 
     # https://en.wikipedia.org/wiki/ISO_3166-2:PT
     subdivisions = (
@@ -64,6 +64,28 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         "20",
         "30",
     )
+    subdivisions_aliases = {
+        "Aveiro": "01",
+        "Beja": "02",
+        "Braga": "03",
+        "Bragança": "04",
+        "Castelo Branco": "05",
+        "Coimbra": "06",
+        "Évora": "07",
+        "Faro": "08",
+        "Guarda": "09",
+        "Leiria": "10",
+        "Lisboa": "11",
+        "Portalegre": "12",
+        "Porto": "13",
+        "Santarém": "14",
+        "Setúbal": "15",
+        "Viana do Castelo": "16",
+        "Vila Real": "17",
+        "Viseu": "18",
+        "Região Autónoma dos Açores": "20",
+        "Região Autónoma da Madeira": "30",
+    }
     _deprecated_subdivisions = ("Ext",)
     supported_languages = ("en_US", "pt_PT", "uk")
 
@@ -148,7 +170,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Carnival.
         self._add_carnival_tuesday(tr("Carnaval"))
 
-        # St. Anthony's Day.
+        # Saint Anthony's Day.
         self._add_holiday_jun_13(tr("Dia de Santo António"))
 
         # Christmas Eve.
@@ -168,7 +190,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
             self._populate_optional_holidays()
 
     def _populate_subdiv_01_public_holidays(self):
-        # St. Joanna's Day.
+        # Saint Joanna's Day.
         self._add_holiday_may_12(tr("Dia de Santa Joana"))
 
     def _populate_subdiv_02_public_holidays(self):
@@ -176,7 +198,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_ascension_thursday(tr("Quinta-feira da Ascensão"))
 
     def _populate_subdiv_03_public_holidays(self):
-        # St. John's Day.
+        # Saint John's Day.
         self._add_saint_johns_day(tr("Dia de São João"))
 
     def _populate_subdiv_04_public_holidays(self):
@@ -184,18 +206,15 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_holiday_aug_22(tr("Dia de Nossa Senhora das Graças"))
 
     def _populate_subdiv_05_public_holidays(self):
-        self._add_holiday(
-            # Feast of Our Lady of Mércoles.
-            tr("Dia de Nossa Senhora de Mércoles"),
-            self._easter_sunday + td(days=+16),
-        )
+        # Feast of Our Lady of Mércoles.
+        self._add_holiday_16_days_past_easter(tr("Dia de Nossa Senhora de Mércoles"))
 
     def _populate_subdiv_06_public_holidays(self):
-        # St. Elizabeth's Day.
+        # Saint Elizabeth's Day.
         self._add_holiday_jul_4(tr("Dia de Santa Isabel"))
 
     def _populate_subdiv_07_public_holidays(self):
-        # St. Peter's Day.
+        # Saint Peter's Day.
         self._add_saints_peter_and_paul_day(tr("Dia de São Pedro"))
 
     def _populate_subdiv_08_public_holidays(self):
@@ -221,7 +240,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_saint_johns_day(tr("Dia de São João"))
 
     def _populate_subdiv_14_public_holidays(self):
-        # St. Joseph's Day.
+        # Saint Joseph's Day.
         self._add_saint_josephs_day(tr("Dia de São José"))
 
     def _populate_subdiv_15_public_holidays(self):
@@ -236,7 +255,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_holiday_jun_13(tr("Dia de Santo António"))
 
     def _populate_subdiv_18_public_holidays(self):
-        # St. Matthew's Day.
+        # Saint Matthew's Day.
         self._add_holiday_sep_21(tr("Dia de São Mateus"))
 
     def _populate_subdiv_20_public_holidays(self):
