@@ -87,11 +87,17 @@ class SriLanka(
     start_year = 1972
     end_year = 2025
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+        """
+        :param islamic_show_estimated:
+            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        """
         ChristianHolidays.__init__(self)
         HinduCalendarHolidays.__init__(self, SriLankaHinduHolidays)
         InternationalHolidays.__init__(self)
-        IslamicHolidays.__init__(self, SriLankaIslamicHolidays)
+        IslamicHolidays.__init__(
+            self, cls=SriLankaIslamicHolidays, show_estimated=islamic_show_estimated
+        )
         SinhalaCalendarHolidays.__init__(self)
         StaticHolidays.__init__(self, cls=SriLankaStaticHolidays)
         super().__init__(*args, **kwargs)
