@@ -7,13 +7,12 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from datetime import timedelta as td
 from gettext import gettext as tr
 
-from holidays.calendars.gregorian import _get_all_sundays
+from holidays.calendars.gregorian import _timedelta, _get_all_sundays
 from holidays.groups import ChristianHolidays, InternationalHolidays
 from holidays.holiday_base import HolidayBase
 
@@ -30,12 +29,15 @@ class Sweden(HolidayBase, ChristianHolidays, InternationalHolidays):
 
     Primary sources:
         - https://sv.wikipedia.org/wiki/Helgdagar_i_Sverige
-        - http://www.riksdagen.se/sv/dokument-lagar/dokument/svensk-forfattningssamling/lag-1989253-om-allmanna-helgdagar_sfs-1989-253  # noqa: E501
+        - http://www.riksdagen.se/sv/dokument-lagar/dokument/svensk-forfattningssamling/lag-1989253-om-allmanna-helgdagar_sfs-1989-253
+        - https://sv.wikipedia.org/wiki/F%C3%B6rsta_maj
+        - https://sv.wikipedia.org/wiki/Sveriges_nationaldag
+        - https://sv.wikipedia.org/wiki/Midsommarafton
     """
 
     country = "SE"
     default_language = "sv"
-    supported_languages = ("en_US", "sv", "uk")
+    supported_languages = ("en_US", "sv", "th", "uk")
 
     def __init__(self, include_sundays=True, *args, **kwargs):
         """
@@ -67,7 +69,6 @@ class Sweden(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Easter Monday.
         self._add_easter_monday(tr("Annandag påsk"))
 
-        # Source: https://sv.wikipedia.org/wiki/F%C3%B6rsta_maj
         if self._year >= 1939:
             # May Day.
             self._add_labor_day(tr("Första maj"))
@@ -75,7 +76,6 @@ class Sweden(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Ascension Day.
         self._add_ascension_thursday(tr("Kristi himmelsfärdsdag"))
 
-        # Source: https://sv.wikipedia.org/wiki/Sveriges_nationaldag
         if self._year >= 2005:
             # National Day of Sweden.
             self._add_holiday_jun_6(tr("Sveriges nationaldag"))
@@ -87,11 +87,6 @@ class Sweden(HolidayBase, ChristianHolidays, InternationalHolidays):
             # Whit Monday.
             self._add_whit_monday(tr("Annandag pingst"))
 
-        # Source:
-        # https://sv.wikipedia.org/wiki/Midsommarafton
-        # https://www.nordiskamuseet.se/aretsdagar/midsommarafton
-        # Midsummer evening. Friday between June 19th and June 25th
-
         # Midsummer Eve.
         name = tr("Midsommarafton")
         dt = (
@@ -101,10 +96,11 @@ class Sweden(HolidayBase, ChristianHolidays, InternationalHolidays):
         )
 
         # Midsummer Day.
-        self._add_holiday(tr("Midsommardagen"), dt + td(days=+1))
+        self._add_holiday(tr("Midsommardagen"), _timedelta(dt, +1))
 
-        # All Saints' Day.
-        self._add_holiday_1st_sat_from_oct_31(tr("Alla helgons dag"))
+        if self._year >= 1953:
+            # All Saints' Day.
+            self._add_holiday_1st_sat_from_oct_31(tr("Alla helgons dag"))
 
         # Christmas Eve.
         self._add_christmas_eve(tr("Julafton"))
