@@ -7,22 +7,21 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from datetime import timedelta as td
 from gettext import gettext as tr
 
-from holidays.calendars.gregorian import APR, THU, _get_nth_weekday_of_month
+from holidays.calendars.gregorian import APR, THU, _timedelta, _get_nth_weekday_of_month
 from holidays.constants import HALF_DAY, OPTIONAL, PUBLIC
 from holidays.groups import ChristianHolidays, InternationalHolidays
-from holidays.holiday_base import HolidayBase
+from holidays.observed_holiday_base import ObservedHolidayBase, MON_ONLY, TUE_TO_NONE, SAT_TO_NONE
 
 
-class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
+class Switzerland(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
     """
     References:
-        - https://www.bj.admin.ch/dam/bj/de/data/publiservice/service/zivilprozessrecht/kant-feiertage.pdf  # noqa: E501
+        - https://www.bj.admin.ch/dam/bj/de/data/publiservice/service/zivilprozessrecht/kant-feiertage.pdf
         - https://de.wikipedia.org/wiki/Feiertage_in_der_Schweiz
         - https://en.wikipedia.org/wiki/Public_holidays_in_Switzerland
     """
@@ -59,6 +58,7 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
     )
     supported_categories = (HALF_DAY, OPTIONAL, PUBLIC)
     supported_languages = ("de", "en_US", "fr", "it", "uk")
+    start_year = 1801
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -67,7 +67,7 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
 
     def _populate_public_holidays(self):
         # New Year's Day.
-        self._add_new_years_day(tr("Neujahrestag"))
+        self._add_new_years_day(tr("Neujahrstag"))
 
         # Ascension Day.
         self._add_ascension_thursday(tr("Auffahrt"))
@@ -79,7 +79,7 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_christmas_day(tr("Weihnachten"))
 
     def _populate_subdiv_ag_public_holidays(self):
-        # Berchtold's Day.
+        # Saint Berchtold's Day.
         self._add_new_years_day_two(tr("Berchtoldstag"))
 
         # Good Friday.
@@ -106,7 +106,7 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Immaculate Conception.
         self._add_immaculate_conception_day(tr("Mariä Empfängnis"))
 
-        # St. Stephen's Day.
+        # Saint Stephen's Day.
         self._add_christmas_day_two(tr("Stephanstag"))
 
     def _populate_subdiv_ar_public_holidays(self):
@@ -116,8 +116,9 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         self._add_whit_monday(tr("Pfingstmontag"))
 
-        if not self._is_monday(self._christmas_day) and not self._is_friday(self._christmas_day):
-            self._add_christmas_day_two(tr("Stephanstag"))
+        self._add_observed(
+            self._add_christmas_day_two(tr("Stephanstag")), rule=TUE_TO_NONE + SAT_TO_NONE
+        )
 
     def _populate_subdiv_ai_public_holidays(self):
         self._add_good_friday(tr("Karfreitag"))
@@ -134,8 +135,9 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         self._add_immaculate_conception_day(tr("Mariä Empfängnis"))
 
-        if not self._is_monday(self._christmas_day) and not self._is_friday(self._christmas_day):
-            self._add_christmas_day_two(tr("Stephanstag"))
+        self._add_observed(
+            self._add_christmas_day_two(tr("Stephanstag")), rule=TUE_TO_NONE + SAT_TO_NONE
+        )
 
     def _populate_subdiv_bl_public_holidays(self):
         self._add_good_friday(tr("Karfreitag"))
@@ -202,7 +204,7 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
             self._add_holiday(
                 # Battle of Naefels Victory Day.
                 tr("Näfelser Fahrt"),
-                dt + td(days=+7) if dt == self._easter_sunday + td(days=-3) else dt,
+                _timedelta(dt, +7) if dt == _timedelta(self._easter_sunday, -3) else dt,
             )
 
         self._add_good_friday(tr("Karfreitag"))
@@ -268,10 +270,10 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
         self._add_christmas_day_two(tr("Stephanstag"))
 
     def _populate_subdiv_ne_public_holidays(self):
-        dt = self._add_new_years_day_two(tr("Berchtoldstag"))
-        # Jan 2 is public holiday only when it falls on Monday (Jan 1 falls on Sunday).
-        if not self._is_monday(dt):
-            self.pop(dt)
+        self._add_observed(
+            self._add_new_years_day_two(tr("Berchtoldstag")),
+            rule=MON_ONLY,  # Jan 2 is public holiday only when it falls on Monday.
+        )
 
         # Republic Day.
         self._add_holiday_mar_1(tr("Jahrestag der Ausrufung der Republik"))
@@ -282,11 +284,10 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         self._add_corpus_christi_day(tr("Fronleichnam"))
 
-        if self._is_sunday(self._christmas_day):
-            self._add_christmas_day_two(tr("Stephanstag"))
+        self._add_observed(self._add_christmas_day_two(tr("Stephanstag")), rule=MON_ONLY)
 
     def _populate_subdiv_nw_public_holidays(self):
-        # St. Joseph's Day.
+        # Saint Joseph's Day.
         self._add_saint_josephs_day(tr("Josefstag"))
 
         self._add_good_friday(tr("Karfreitag"))
@@ -315,7 +316,7 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         self._add_assumption_of_mary_day(tr("Mariä Himmelfahrt"))
 
-        # St. Nicholas of Flüe.
+        # Saint Nicholas of Flüe.
         self._add_holiday_sep_25(tr("Bruder Klaus"))
 
         self._add_all_saints_day(tr("Allerheiligen"))
@@ -446,8 +447,9 @@ class Switzerland(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         self._add_immaculate_conception_day(tr("Mariä Empfängnis"))
 
-        if not self._is_monday(self._christmas_day) and not self._is_friday(self._christmas_day):
-            self._add_christmas_day_two(tr("Stephanstag"))
+        self._add_observed(
+            self._add_christmas_day_two(tr("Stephanstag")), rule=TUE_TO_NONE + SAT_TO_NONE
+        )
 
     def _populate_subdiv_vd_public_holidays(self):
         self._add_new_years_day_two(tr("Berchtoldstag"))
