@@ -38,9 +38,15 @@ class Turkey(HolidayBase, InternationalHolidays, IslamicHolidays, StaticHolidays
     # Law 2739 of 27 May 1935.
     start_year = 1936
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+        """
+        :param islamic_show_estimated:
+            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        """
         InternationalHolidays.__init__(self)
-        IslamicHolidays.__init__(self, TurkeyIslamicHolidays)
+        IslamicHolidays.__init__(
+            self, cls=TurkeyIslamicHolidays, show_estimated=islamic_show_estimated
+        )
         StaticHolidays.__init__(self, TurkeyStaticHolidays)
         super().__init__(*args, **kwargs)
 
