@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 
@@ -24,13 +24,19 @@ def _normalize_arguments(cls, value):
         A set created from `value` argument.
 
     """
-    if isinstance(value, cls):
-        return {value}
+    if value is None:
+        return set()
 
-    return set(value) if value is not None else set()
+    if isinstance(value, str):
+        return {cls(value)}
+
+    try:
+        return {cls(v) for v in value}
+    except TypeError:  # non-iterable
+        return {cls(value)}
 
 
-def _normalize_tuple(data):
+def _normalize_tuple(value):
     """Normalize tuple.
 
     :param data:
@@ -40,4 +46,4 @@ def _normalize_tuple(data):
         An unchanged object for tuple of tuples, e.g., ((JAN, 10), (DEC, 31)).
         An object put into a tuple otherwise, e.g., ((JAN, 10),).
     """
-    return data if not data or isinstance(data[0], tuple) else (data,)
+    return value if not value or isinstance(value[0], tuple) else (value,)
