@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.constants import UNOFFICIAL
+from holidays.constants import GOVERNMENT, UNOFFICIAL
 from holidays.countries.united_states_minor_outlying_islands import HolidaysUM, UM, UMI
 from tests.common import CommonCountryTests
 
@@ -35,3 +35,19 @@ class TestUM(CommonCountryTests, TestCase):
             ("2024-03-17", "Saint Patrick's Day"),
             ("2024-10-31", "Halloween"),
         )
+
+    def test_government_holidays(self):
+        self.assertHolidays(
+            HolidaysUM(categories=GOVERNMENT, years=2024),
+            ("2024-01-01", "New Year's Day"),
+            ("2024-01-15", "Birthday of Martin Luther King, Jr."),
+            ("2024-02-19", "Washington's Birthday"),
+            ("2024-05-27", "Memorial Day"),
+            ("2024-06-19", "Juneteenth National Independence Day"),
+            ("2024-07-04", "Independence Day"),
+            ("2024-09-02", "Labor Day"),
+            ("2024-10-14", "Columbus Day"),
+            ("2024-11-11", "Veterans Day"),
+            ("2024-11-28", "Thanksgiving Day"),
+            ("2024-12-25", "Christmas Day"),
+        )
