@@ -867,6 +867,16 @@ class TestSerialization(unittest.TestCase):
         self.assertEqual(loaded_holidays, self.hb)
         self.assertIn(dt, self.hb)
 
+    def test_pickle_localized_entity(self):
+        for lang in ("uk", "en_US", None):
+            ua = UA(language=lang)
+            dt = "2021-01-01"
+            self.assertIn(dt, self.hb)
+
+            loaded_ua = pickle.loads(pickle.dumps(ua))
+            self.assertEqual(loaded_ua, ua)
+            self.assertIn(dt, loaded_ua)
+
 
 class TestSpecialHolidays(unittest.TestCase):
     def setUp(self):
